export { AIGatewayService, type AIGatewayChatCompletion, type AIGatewayChatCompletionParams, type AIGatewayChatMessage, type AIGatewayModel, type AIGatewayModelProvider, type AIGatewayModels, type AIGatewayModelsResponse, type AIGatewayPricing, AIGatewayChatCompletionParamsSchema, AIGatewayChatCompletionSchema, AIGatewayChatMessageSchema, AIGatewayModelProviderSchema, AIGatewayModelSchema, AIGatewayModelsResponseSchema, AIGatewayModelsSchema, AIGatewayPricingSchema, } from '@agentuity/core/aigateway';
import { type AIGatewayChatCompletion, type AIGatewayChatCompletionParams, type AIGatewayModels } from '@agentuity/core/aigateway';
import { type Logger } from '@agentuity/server';
import { z } from 'zod';
export declare const AIGatewayClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type AIGatewayClientOptions = z.infer<typeof AIGatewayClientOptionsSchema>;
export declare class AIGatewayClient {
    #private;
    constructor(options?: AIGatewayClientOptions);
    listModels(): Promise<AIGatewayModels>;
    complete(params: AIGatewayChatCompletionParams): Promise<AIGatewayChatCompletion>;
}
//# sourceMappingURL=index.d.ts.map